============
conclas
============
The conclas is a client written in Python to use the service Conclas.

============
Install
============
Conclas Python Client can be installed using pip:

.. code:: 

  $ pip install conclas

If you prefer to install manually, you must follow the following steps. First clone the repository client python conclas. This is the `link <http://conclas.com>`_
. After cloning the repository run the following command:

.. code::

  $ python setup.py install

============
Examples
============
The example of using the client python conclas are in the examples folder. To test it run the following command:

.. code::

  $ python examples/simple.py

==============
Running tests
==============
To run the tests, run the following command:

.. code::

  $ python tests/conclas/test_conclas.py

==============
Documentation
==============
To understand more about the client python conclas, see our `documentation <http://conclas-platform.cleverapps.io/docs/>`_
.